Index: AE/Installer/trunk/source/main_window.cpp
===================================================================
--- AE/Installer/trunk/source/main_window.cpp	(revision 327)
+++ AE/Installer/trunk/source/main_window.cpp	(revision 328)
@@ -937,5 +937,5 @@
     EVT_RADIOBUTTON( NoSep_RadioButton, MainWindow::OnNoSepRadioButtonSelected )
 
-    EVT_RADIOBUTTON( Separated_RadioButton, MainWindow::OnSeparatedRadioButtonSelected )
+    EVT_RADIOBUTTON( Seperated_RadioButton, MainWindow::OnSeperatedRadioButtonSelected )
 
     EVT_RADIOBUTTON( Complete_RadioButton, MainWindow::OnCompleteRadioButtonSelected )
@@ -1022,5 +1022,5 @@
     SepRadio = NULL;
     NoSepRadio = NULL;
-    SeparatedRadio = NULL;
+    SeperatedRadio = NULL;
     CompleteRadio = NULL;
     ReglobalizeButton = NULL;
@@ -1039,4 +1039,6 @@
 {    
 ////@begin MainWindow content construction
+    // Generated by DialogBlocks, 31/05/2009 19:03:55 (unregistered)
+
     MainWindow* itemFrame1 = this;
 
@@ -1124,5 +1126,5 @@
     itemBoxSizer11->Add(itemStaticLine17, 0, wxGROW|wxALL, 5);
 
-    descriptionText = new wxTextCtrl( itemPanel10, Description_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_MULTILINE|wxTE_READONLY|wxTE_RICH|wxTE_RICH2 );
+    descriptionText = new wxTextCtrl( itemPanel10, Description_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_MULTILINE|wxTE_READONLY|wxTE_RICH|wxTE_AUTO_URL );
     descriptionText->SetName(_T("DescriptionName"));
     descriptionText->SetBackgroundColour(wxColour(240, 240, 240));
@@ -1141,9 +1143,9 @@
     itemBoxSizer2->Add(itemBoxSizer20, 0, wxGROW|wxALL, 0);
 
-    ProgressBar = new wxGauge( itemFrame1, ProgressBar_Gauge, 1000, wxDefaultPosition, wxDefaultSize, wxGA_SMOOTH );
+    ProgressBar = new wxGauge( itemFrame1, ProgressBar_Gauge, 1000, wxDefaultPosition, wxSize(-1, 30), wxGA_SMOOTH );
     ProgressBar->SetValue(0);
     itemBoxSizer20->Add(ProgressBar, 1, wxGROW|wxALL, 0);
 
-    InstallButton = new wxButton( itemFrame1, Install_Button, _("Install!"), wxDefaultPosition, wxDefaultSize, 0 );
+    InstallButton = new wxButton( itemFrame1, Install_Button, _("Install!"), wxDefaultPosition, wxSize(-1, 30), 0 );
     itemBoxSizer20->Add(InstallButton, 0, wxGROW|wxALL, 0);
 
@@ -1178,8 +1180,8 @@
     itemBoxSizer25->Add(itemBoxSizer30, 0, wxGROW|wxALL, 5);
 
-    SeparatedRadio = new wxRadioButton( OptionsPanel, Separated_RadioButton, _("Separated Level0"), wxDefaultPosition, wxDefaultSize, wxRB_GROUP );
-    SeparatedRadio->SetValue(false);
-    SeparatedRadio->SetName(_T("Separated_RadioButton"));
-    itemBoxSizer30->Add(SeparatedRadio, 0, wxALIGN_LEFT|wxALL, 5);
+    SeperatedRadio = new wxRadioButton( OptionsPanel, Seperated_RadioButton, _("Separated Level0"), wxDefaultPosition, wxDefaultSize, wxRB_GROUP );
+    SeperatedRadio->SetValue(false);
+    SeperatedRadio->SetName(_T("Seperated_RadioButton"));
+    itemBoxSizer30->Add(SeperatedRadio, 0, wxALIGN_LEFT|wxALL, 5);
 
     CompleteRadio = new wxRadioButton( OptionsPanel, Complete_RadioButton, _("Complete Level0"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -1634,2 +1636,15 @@
 }
 
+
+/*
+ * wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Seperated_RadioButton
+ */
+
+void MainWindow::OnSeperatedRadioButtonSelected( wxCommandEvent& event )
+{
+////@begin wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Seperated_RadioButton in MainWindow.
+    // Before editing this code, remove the block markers.
+    event.Skip();
+////@end wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Seperated_RadioButton in MainWindow. 
+}
+
Index: AE/Installer/trunk/source/main_window.h
===================================================================
--- AE/Installer/trunk/source/main_window.h	(revision 327)
+++ AE/Installer/trunk/source/main_window.h	(revision 328)
@@ -57,10 +57,10 @@
 #define Sep_RadioButton 10013
 #define NoSep_RadioButton 10014
-#define Separated_RadioButton 10015
+#define Seperated_RadioButton 10015
 #define Complete_RadioButton 10016
 #define ReGlobalize_Button 10018
 #define wxID_LOAD 10006
 #define wxID_OPTIONS 10017
-#define SYMBOL_MAINWINDOW_STYLE wxCAPTION|wxRESIZE_BORDER|wxSYSTEM_MENU|wxMINIMIZE_BOX|wxMAXIMIZE_BOX|wxCLOSE_BOX
+#define SYMBOL_MAINWINDOW_STYLE wxCAPTION|wxRESIZE_BORDER|wxSYSTEM_MENU|wxMINIMIZE_BOX|wxMAXIMIZE_BOX|wxCLOSE_BOX|wxSIMPLE_BORDER
 #define SYMBOL_MAINWINDOW_TITLE _("Installer")
 #define SYMBOL_MAINWINDOW_IDNAME ID_MAINWINDOW
@@ -128,6 +128,6 @@
     void OnNoSepRadioButtonSelected( wxCommandEvent& event );
 
-    /// wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Separated_RadioButton
-    void OnSeparatedRadioButtonSelected( wxCommandEvent& event );
+    /// wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Seperated_RadioButton
+    void OnSeperatedRadioButtonSelected( wxCommandEvent& event );
 
     /// wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Complete_RadioButton
@@ -180,5 +180,5 @@
     wxRadioButton* SepRadio;
     wxRadioButton* NoSepRadio;
-    wxRadioButton* SeparatedRadio;
+    wxRadioButton* SeperatedRadio;
     wxRadioButton* CompleteRadio;
     wxButton* ReglobalizeButton;
